@@ -2,7 +2,7 @@
 
 ################################################################################
 #
-# $Id: OutLogger.pm 38 2008-05-29 03:26:09Z aijaz $
+# $Id: OutLogger.pm 39 2008-06-01 22:36:48Z aijaz $
 #
 ################################################################################
 
@@ -12,7 +12,8 @@ TaskForest::OutLogger - Functions related to logging to stdout
 
 =head1 DOCUMENTATION
 
-More documentation will be made available in release 1.12
+This is a class that is used to tie prints to STDOUT to $log->info();
+See Logger::Log4perl for more details. 
 
 =cut
 
@@ -27,7 +28,7 @@ use Log::Log4perl;
 
 BEGIN {
     use vars qw($VERSION);
-    $VERSION     = '1.11';
+    $VERSION     = '1.12';
 }
 
 sub TIEHANDLE {
